#include "mainwindow.h"
#include <QVBoxLayout>
#include <QSettings>
#include <QMenuBar>
#include <QDebug>
#include <QSignalMapper>

MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent) {
    QVBoxLayout *mainLayout = new QVBoxLayout;

    centralPanel = new QWidget;
    centralPanel->setLayout(mainLayout);

    customButton = new QPushButton("Valider");
    input = new QLineEdit();

    mainLayout->addWidget(input);
    mainLayout->addWidget(customButton);
    setCentralWidget(centralPanel);

    QSettings settings("QSettingsExample", "QSettingsExampleSettings");
    settings.beginGroup("general");
    currentTheme = settings.value("currentTheme", BLACK).value<int>();
    settings.endGroup();

    createMenu();
    setThemes(currentTheme);
}

void MainWindow::closeEvent(QCloseEvent* event){
    QSettings settings("QSettingsExample", "QSettingsExampleSettings");
    settings.clear();

    settings.beginGroup("general");
    settings.setValue("currentTheme", currentTheme);
    settings.endGroup();

    event->accept();
}

void MainWindow::setThemes(int theme) {
    if(theme == BLACK) {
        input->setStyleSheet("background: #484848; padding: 3px 5px; border: 1px solid #E8E8E8; color: white;");
        centralPanel->setStyleSheet("background: #121212; border: 0; padding: 0; margin : 0;");
        menuBar()->setStyleSheet("QMenuBar { background: #121212; color: #B5B5B5; } QMenu { background: black; } QMenuBar::item { background-color: transparent; }");
    } else {
        input->setStyleSheet("background: white; padding: 3px 5px; border: 1px solid #484848; color: black;");
        centralPanel->setStyleSheet("background: white; border: 0; padding: 0; margin : 0;");
        menuBar()->setStyleSheet("QMenuBar { background: white; color: black; } QMenu { background: white; color: black; } QMenuBar::item { background-color: transparent; }");
    }
    customButton->setStyleSheet("QPushButton { background: #25A2D8; color: white; border: none; padding: 8px 15px; margin: 0; } QPushButton:hover { background: #45B2E9; } ");
}


void MainWindow::createMenu() {
    QMenu* file = menuBar()->addMenu("Fichier");
    quit = file->addAction("Quitter", this, SLOT(close()));
    quit->setShortcut(Qt::CTRL + Qt::Key_Q);

    QMenu* themes = menuBar()->addMenu("Thèmes");
    white = themes->addAction("Blanc");
    black = themes->addAction("Noir");

    QSignalMapper *mapper = new QSignalMapper;
    mapper->setMapping(white, WHITE);
    mapper->setMapping(black, BLACK);

    connect(white, SIGNAL(triggered()), mapper, SLOT(map()));
    connect(black, SIGNAL(triggered()), mapper, SLOT(map()));
    connect(mapper, SIGNAL(mapped(int)), this, SLOT(changeCurrentTheme(int)));
}

void MainWindow::changeCurrentTheme(int newTheme) {
    currentTheme = newTheme;
    setThemes(currentTheme);
}
